@@ -1,10 +1,10 @@
-__version__ = "0.12.1"
-__keywords__ = ["encrypted socket server client"]
+__version__ = "1.1.0"
+__keywords__ = ["encrypted rpc socket server client"]
 
 
 if not __version__.endswith(".0"):
     import re
-    print(f"version {__version__} is deployed for automatic commitments only", flush=True)
+    print("version {} is deployed for automatic commitments only".format(__version__), flush=True)
     print("install version " + re.sub(r"([0-9]+\.[0-9]+\.)[0-9]+", r"\g<1>0", __version__) + " instead")
     import os
     os._exit(1)
