@@ -24,7 +24,7 @@ class SC(object):
         else:
             raise Exception("current connection is under MITM attack")
 
-    def request(self, command: str, data: Any = None) -> Any:
+    def request(self, command: str, data: Tuple[Tuple, Dict] = args()) -> Any:
         request = dict(command=command, data=data)
         try:
             request = jd_and_utf8e(request)
