@@ -3,7 +3,7 @@ import socket
 import pickle
 import threading
 from .utils import *
-from omnitools import encryptedsocket_function, p, utf8d, key_pair_format
+from omnitools import encryptedsocket_function, p, utf8d, key_pair_format, dt2yyyymmddhhmmss
 from debugging import *
 from easyrsa import *
 
@@ -13,8 +13,10 @@ __ALL__ = ["SS"]
 
 class SS(object):
     def __init__(self, key_pair: key_pair_format, functions: encryptedsocket_function = None,
-                 host: str = "127.199.71.10", port: int = 39291) -> None:
+                 host: str = "127.199.71.10", port: int = 39291,
+                 silent: bool = False) -> None:
         self.terminate = False
+        self.silent = silent
         self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.s.bind((host, int(port)))
         self.s.listen(5)
@@ -26,8 +28,9 @@ class SS(object):
         self.pkey = lambda: key_pair["public_key"]
 
     def handler(self, conn: socket.socket, addr: tuple) -> None:
-        uid = addr[0]+":"+str(addr[1])
-        p(f"connected\t{uid}")
+        uid = "{}:{}".format(*addr)
+        if not self.silent:
+            p("{}\tconnected\t{}".format(dt2yyyymmddhhmmss(), uid))
         try:
             while True:
                 request = utf8d(recv_all(conn))
@@ -38,22 +41,19 @@ class SS(object):
                     request = decrypt(self.__key[uid], request)
                 else:
                     request = jl(request)
-                if request["command"] == "get_pkey" and uid not in self.__key:
-                    v = self.pkey()
-                    response = (
-                        b64e(self.sign(v)),
-                        b64e(v)
-                    )
-                elif request["command"] in self.functions:
-                    try:
+                try:
+                    if request["command"] == "get_pkey" and uid not in self.__key:
+                        v = self.pkey()
+                        response = (
+                            b64e(self.sign(v)),
+                            b64e(v)
+                        )
+                    elif request["command"] in self.functions:
                         response = self.functions[request["command"]](*request["data"][0], **request["data"][1])
-                    except:
-                        response = debug_info()
-                else:
-                    try:
+                    else:
                         raise Exception("request command '{}' is not in socket functions".format(request["command"]))
-                    except:
-                        response = debug_info()
+                except:
+                    response = debug_info()
                 try:
                     from omnitools import jd_and_utf8e
                     response = jd_and_utf8e(response)
@@ -72,7 +72,8 @@ class SS(object):
             p(debug_info()[0])
         finally:
             conn.close()
-            p(f"disconnected\t{uid}")
+            if not self.silent:
+                p("{}\tdisconnected\t{}".format(dt2yyyymmddhhmmss(), uid))
 
     def start(self) -> None:
         try:
