@@ -25,7 +25,7 @@ def recv_all(conn: socket.socket) -> bytes:
 def encrypt(key: str_or_bytes, plaintext: str_or_bytes) -> bytes:
     ciphertext = AESCipher(key).encrypt(plaintext)
     hash = mac(key, ciphertext)
-    return f"{hash} {ciphertext}".encode("utf-8")
+    return "{} {}".format(hash, ciphertext).encode("utf-8")
 
 
 def decrypt(key: str_or_bytes, ciphertext: str) -> Any:
